==> haskell-data-binary-ieee754-0.4.4-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-binary-ieee754.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-binary-ieee754
version:              0.4.4
visibility:           public
id:                   data-binary-ieee754-0.4.4-HlSlHq1qDaTKAKUZNW5rdz
key:                  data-binary-ieee754-0.4.4-HlSlHq1qDaTKAKUZNW5rdz
license:              MIT
maintainer:           John Millikin <jmillikin@gmail.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://john-millikin.com/software/data-binary-ieee754/
synopsis:             Parser/Serialiser for IEEE-754 floating-point values
description:          Convert Float and Decimal values to/from raw octets.
category:             Data
abi:                  59c025aefbddc94aa86e927a8f605052
exposed:              True
exposed-modules:      Data.Binary.IEEE754
import-dirs:          /usr/lib/ghc-8.10.4/site-local/data-binary-ieee754-0.4.4
library-dirs:         /usr/lib/ghc-8.10.4/site-local/data-binary-ieee754-0.4.4
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/data-binary-ieee754-0.4.4

hs-libraries:         HSdata-binary-ieee754-0.4.4-HlSlHq1qDaTKAKUZNW5rdz
depends:              base-4.14.1.0 binary-0.8.8.0
haddock-interfaces:
    /usr/share/doc/haskell-data-binary-ieee754/html/data-binary-ieee754.haddock

haddock-html:         /usr/share/doc/haskell-data-binary-ieee754/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-binary-ieee754-0.4.4-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-binary-ieee754.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-binary-ieee754
version:              0.4.4
visibility:           public
id:                   data-binary-ieee754-0.4.4-BBofvLKootn8l57SJnz736
key:                  data-binary-ieee754-0.4.4-BBofvLKootn8l57SJnz736
license:              MIT
maintainer:           John Millikin <jmillikin@gmail.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://john-millikin.com/software/data-binary-ieee754/
synopsis:             Parser/Serialiser for IEEE-754 floating-point values
description:          Convert Float and Decimal values to/from raw octets.
category:             Data
abi:                  a8fad956983a5acbb8db5caac58ad309
exposed:              True
exposed-modules:      Data.Binary.IEEE754
import-dirs:          /usr/lib/ghc-8.10.5/site-local/data-binary-ieee754-0.4.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/data-binary-ieee754-0.4.4
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.5/data-binary-ieee754-0.4.4

hs-libraries:         HSdata-binary-ieee754-0.4.4-BBofvLKootn8l57SJnz736
depends:              base-4.14.2.0 binary-0.8.8.0
haddock-interfaces:
    /usr/share/doc/haskell-data-binary-ieee754/html/data-binary-ieee754.haddock

haddock-html:         /usr/share/doc/haskell-data-binary-ieee754/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
